@@ -11,7 +11,7 @@ print(y.shape)
 a = Activations()
 activation = a.tanh
 derivative1 = a.tanh_derivative
-classifier = a.linear
+resolver = a.linear
 derivative2 = a.linear_derivative
 
 l = Loss()
@@ -23,13 +23,20 @@ output = y
 features = x.shape[1]
 architecture = [2,4,1]
 learning_rate = 0.01
-epochs = 10000
+epochs = 1000
 
-model = NN(features,architecture,activation,derivative1,classifier,derivative2,loss,derivative3,learning_rate)
-model.train(input,output,epochs)
+model = NN(features,architecture,activation,derivative1,resolver,derivative2,loss,derivative3,learning_rate)
+model.train(input,output,epochs,verbose=True,step=100,autosave=True)
 prediction = model.predict(input)
 
 print("prediction")
 print(prediction)
 print("expected")
 print(y)
+
+from nillanet.io import IO
+io = IO()
+best = io.load(model.backup)
+prediction = best.predict(x)
+print("best")
+print(prediction)
\ No newline at end of file
